runsolver.d runsolver.o: runsolver.cc \
 /home/snelleman/anaconda3/envs/sparkle-dev/include/numa.h Cores.hh \
 SignalNames.hh ProcessList.hh CircularBufferFilter.hh \
 ExecutionSummary.hh Watcher.hh ProcessTree.hh ProcessData.hh \
 ProcessHistory.hh TimeStamper.hh
